from .epub import NovelEpub
from .novelsave import NovelSave
from .sourcesave import SourceNovelSave
from .template import NovelSaveTemplate
from .websave import WebNovelSave

__version__ = '0.5.4'
